@@ -6,10 +6,8 @@ pygtk.require('2.0')
 import gtk
 import abiword
 
-window = gtk.Window(type=gtk.WINDOW_TOPLEVEL)
+window = gtk.Window()
 window.set_default_size(640, 480)
-window.resize(640,480)
-window.show()
 window.connect('delete-event', gtk.main_quit)
 
 box = gtk.VBox()
@@ -34,5 +32,5 @@ def _clicked_cb(widget, abi, i):
     i.props.pixbuf = abi.render_page_to_image(0)
 
 b.connect('clicked', lambda widget: _clicked_cb(widget, abi, i))
-window.show_all()
+
 gtk.main()
